%define enable_clisp	1
%define enable_cmucl	0
%define enable_gcl	1
%define defaultlisp	gcl

%ifarch x86_64
%define enable_clisp	0
%endif

%if %enable_clisp
%define clisp_flags	--enable-clisp
%else
%define clisp_flags	--disable-clisp
%endif

%if %enable_cmucl
%define cmucl_flags	--enable-cmucl
%else
%define cmucl_flags	--disable-cmucl
%endif

%if %enable_gcl
%define gcl_flags	--enable-gcl
%else
%define gcl_flags	--disable-gcl
%endif

Summary:	Maxima Symbolic Computation Program
Name: 		maxima
Version: 	5.14.0
Release: 	%mkrel 2
License: 	GPL+
Group: 		Sciences/Mathematics
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
URL: 		http://maxima.sourceforge.net
Source0:	http://prdownloads.sourceforge.net/maxima/%{name}-%{version}.tar.bz2
Source1:	icons-%{name}.tar.bz2
Patch0:		maxima-5.13.0-xdg-utils.patch
Patch1:		maxima-5.14.0-lapack-texi.patch
Patch2:		maxima-5.14.0-missed-extract-categories.patch
BuildRequires:	texinfo
BuildRequires:	tetex
BuildRequires:	tetex-latex
BuildRequires:	tetex-dvips
BuildRequires:	python
Requires: 	tk
Requires:       tcl
Requires:	maxima-runtime
Requires:	gnuplot
%if %{enable_clisp}
BuildRequires:	clisp
%endif
%if %{enable_cmucl}
BuildRequires:	cmucl
%endif
%if %{enable_gcl}
BuildRequires:	gcl >= 2.5.3
%endif

%description
Maxima is a full symbolic computation program.  It is full featured
doing symbolic manipulation of polynomials, matrices, rational
functions, integration, Todd-coxeter, graphing, bigfloats.  It has a
symbolic debugger source level debugger for maxima code.  Maxima is
based on the original Macsyma developed at MIT in the 1970's.  It is
quite reliable, and has good garbage collection, and no memory leaks.
It comes with hundreds of self tests.

#--------------------------------------------------------------------

%package gui
Summary: Tcl/Tk GUI interface to Maxima
Group:		Sciences/Mathematics
Requires:	maxima
Requires:	tk
Provides:	xmaxima = %{version}-%{release}
%description gui
Tcl/Tk GUI interface to Maxima.

%files gui
%defattr(-,root,root)
%{_bindir}/xmaxima
%{_datadir}/applications/mandriva-%{name}.desktop
%{_iconsdir}/hicolor/*/apps/*.png

#--------------------------------------------------------------------

%if %{enable_clisp}
%package runtime-clisp
Summary: Maxima compiled with clisp
Group: Sciences/Mathematics
Requires:	clisp
Requires:	maxima = %{version}-%{release}
Provides:	maxima-runtime = %{version}-%{release}
%description runtime-clisp
Maxima compiled with clisp.

%files runtime-clisp
%defattr(-,root,root)
%{_libdir}/maxima/%{version}/binary-clisp/*
%endif

#--------------------------------------------------------------------

%if %{enable_cmucl}
%package runtime-cmucl
Summary: Maxima compiled with CMUCL
Group: Sciences/Mathematics
Requires:	cmucl
Requires:	maxima = %{version}-%{release}
Provides:	maxima-runtime = %{version}-%{release}
%description runtime-cmucl
Maxima compiled with CMUCL.


%files runtime-cmucl
%defattr(-,root,root)
%{_libdir}/maxima/%{version}/binary-cmucl/*
%endif

#--------------------------------------------------------------------

%if %{enable_gcl}
%package runtime-gcl
Summary: Maxima compiled with GCL
Group: 		Sciences/Mathematics
Requires:	maxima = %{version}-%{release}
Suggests:	rlwrap
Provides:	maxima-runtime = %{version}-%{release}
%description runtime-gcl
Maxima compiled with Gnu Common Lisp.

%files runtime-gcl
%defattr(-,root,root)
%{_bindir}/rmaxima
%{_libdir}/maxima/%{version}/binary-gcl/*
%endif

#--------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1 -b .xdg
%patch1 -p1
%patch2 -p1 -b .extract

%build
export GCL_ANSI=y
CFLAGS="%optflags -fno-fast-math" \
CXXFLAGS="%optflags -fno-fast-math" \
%configure2_5x \
	%{clisp_flags} \
	%{gcl_flags} \
	%{cmucl_flags} \
	--with-default-lisp=%{defaultlisp}

make
make check

(cd doc/info
texi2dvi -p -t @afourpaper -t @finalout maxima.texi
)

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

# menu
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}.desktop << EOF
[Desktop Entry]
Name=Maxima
Comment=Tcl/Tk interface to Maxima
Exec=%{_bindir}/xmaxima
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Math;
EOF

# icons
mkdir -p $RPM_BUILD_ROOT%{_iconsdir}
tar xjf %{SOURCE1} -C $RPM_BUILD_ROOT%{_iconsdir}

# don't compress info pages
export EXCLUDE_FROM_COMPRESS=info

%post
%_install_info maxima.info
%update_icon_cache hicolor

%postun
%_remove_install_info maxima.info
%clean_icon_cache hicolor

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog INSTALL README README.lisps
%doc doc/info/maxima.pdf
%{_bindir}/maxima
%{_libdir}/maxima/%{version}/mgnuplot
%{_datadir}/maxima/%{version}/*
%{_infodir}/*.info*
%{_infodir}/maxima-index.lisp*
%{_mandir}/man1/maxima.*



%changelog
* Fri Apr 25 2008 Giuseppe Ghibò <ghibo@mandriva.com> 5.14.0-2mdv2007.1
+ Revision: 197362
- Added tetex-latex, tetex-dvips and python to BuildRequires.
- Added Patch1, Patch2 to fix documentation.
- Fixed docs.

* Sat Apr 19 2008 Giuseppe Ghibò <ghibo@mandriva.com> 5.14.0-1mdv2009.0
+ Revision: 195775
- Release 5.14.0.

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix no-buildroot-tag

* Mon Jan 28 2008 Adam Williamson <awilliamson@mandriva.com> 5.13.0-5mdv2008.1
+ Revision: 158937
- runtime-gcl suggests rlwrap (Fred Himpe, #36035)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 24 2007 Adam Williamson <awilliamson@mandriva.com> 5.13.0-4mdv2008.0
+ Revision: 92661
- correct binary name in menu entry (launch xmaxima, the graphical front end, not maxima, the console one: bug #33930)

* Fri Sep 21 2007 Adam Williamson <awilliamson@mandriva.com> 5.13.0-3mdv2008.0
+ Revision: 92040
- no longer requires gv due to patch
- add maxima-5.13.0-xdg-utils.patch to use xdg-open instead of specific binaries (from Gentoo, MDV bug #33867)

* Wed Sep 05 2007 Adam Williamson <awilliamson@mandriva.com> 5.13.0-2mdv2008.0
+ Revision: 80500
- reduce menu categories as per frederik

* Tue Sep 04 2007 Adam Williamson <awilliamson@mandriva.com> 5.13.0-1mdv2008.0
+ Revision: 79401
- add more menu categories
- slightly rearrange spec
- regenerate icons-maxima.tar.bz2 to use fd.o icon naming scheme
- use Fedora license policy (GPL+)
- new release 5.13.0

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Sun May 27 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.12.0-2mdv2008.0
+ Revision: 31828
- Rebuild against new Maxima

* Tue May 08 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.12.0-1mdv2008.0
+ Revision: 25348
- New version


* Fri Jan 05 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.11.0-2mdv2007.0
+ Revision: 104538
- Rediff Patch0

* Fri Jan 05 2007 Nicolas Lécureuil <neoclust@mandriva.org> 5.11.0-1mdv2007.1
+ Revision: 104408
- New version  5.11.0
- Add Menu entry
- Import maxima

* Wed Apr 12 2006 Giuseppe Ghib <ghibo@mandriva.com> 5.9.3-1mdk
- Release 5.9.3.

* Mon Nov 07 2005 Giuseppe Ghib <ghibo@mandriva.com> 5.9.2-1mdk
- Release 5.9.2.
- Rebuilt Patch0.

* Thu Aug 04 2005 Giuseppe Ghib <ghibo@mandriva.com> 5.9.1-5mdk
- Rebuilt against gcl 2.6.7-0.cvs20050803 and gcc 4.0.1.

* Mon Apr 18 2005 Giuseppe Ghib <ghibo@mandriva.com> 5.9.1-4mdk
- Don't use clisp for X86-64 for now (clisp failed to build
  under X86-64).

* Thu Feb 17 2005 Giuseppe Ghib <ghibo@mandrakesoft.com> 5.9.1-3mdk
- Added gv in Requires.

* Wed Feb 16 2005 Giuseppe Ghib <ghibo@mandrakesoft.com> 5.9.1-2mdk
- Added Patch0 (use gv instead of ghostview).

* Wed Feb 16 2005 Giuseppe Ghib <ghibo@mandrakesoft.com> 5.9.1-1mdk
- Release: 5.9.1.

* Wed Mar 24 2004 Giuseppe Ghib <ghibo@mandrakesoft.com> 5.9.0-6mdk
- Fixed typo in menu entry.

